%define docver  2.4
%define dirver  2.4

%define lib_major	%{dirver}
%define lib_name_orig	libpython
%define lib_name	%mklibname %{name} %{lib_major}

%define subrel	1

Summary:	An interpreted, interactive object-oriented programming language
Name:		python
Version:	2.4.1
Release:	%mkrel 6
License:	Modified CNRI Open Source License
Group:		Development/Python

Source:		http://www.python.org/ftp/python/%{version}/Python-%{version}.tar.bz2
Source1:	http://www.python.org/ftp/python/doc/%{docver}/html-%{docver}.tar.bz2
Source2:	python-2.4-base.list.bz2
Source3:	exclude.py

# Don't include /usr/local/* in search path
Patch3:		Python-2.3-no-local-incpath.patch.bz2

# Support */lib64 convention on x86_64, sparc64, etc.
Patch4:		Python-2.4.1-lib64.patch.bz2

# Do handle <asm-XXX/*.h> headers in h2py.py
# FIXME: incomplete for proper bi-arch support as #if/#else/#endif
# clauses generally should have been handled
Patch5:		Python-2.2.2-biarch-headers.patch.bz2

# detect and link with gdbm_compat for dbm module
Patch6:		Python-2.4.1-gdbm.patch.bz2
Patch7:		python-2.4.3-CVE-2006-4980.patch

URL:		http://www.python.org/
Icon:		python-logo.xpm
Buildroot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot
Conflicts:	tkinter < %{version}
Requires:	%{lib_name} = %{version}
Requires:	%{name}-base = %{version}
BuildRequires:	XFree86-devel 
BuildRequires:	blt
BuildRequires:	db2-devel, db4-devel
BuildRequires:	emacs-bin
BuildRequires:	expat-devel
BuildRequires:	gdbm-devel 
BuildRequires:	gmp-devel
BuildRequires:	ncurses-devel 
BuildRequires:	openssl-devel 
BuildRequires:	readline-devel 
BuildRequires:	termcap-devel
BuildRequires:	tcl tk tix autoconf2.5

%description
Python is an interpreted, interactive, object-oriented programming
language often compared to Tcl, Perl, Scheme or Java. Python includes
modules, classes, exceptions, very high level dynamic data types and
dynamic typing. Python supports interfaces to many system calls and
libraries, as well as to various windowing systems (X11, Motif, Tk,
Mac and MFC).

Programmers can write new built-in modules for Python in C or C++.
Python can be used as an extension language for applications that
need a programmable interface. This package contains most of the
standard Python modules, as well as modules for interfacing to the
Tix widget set for Tk and RPM.

Note that documentation for Python is provided in the python-docs
package.

%package -n	%{lib_name}
Summary:	Shared libraries for Python %{version}
Group:		System/Libraries
PreReq:		/sbin/ldconfig

%description -n	%{lib_name}
This packages contains Python shared object library.  Python is an
interpreted, interactive, object-oriented programming language often
compared to Tcl, Perl, Scheme or Java.

%package -n	%{lib_name}-devel
Summary:	The libraries and header files needed for Python development
Group:		Development/Python
Icon:		python-devel-logo.xpm
Requires:	%{name} = %version
Requires:	%{lib_name} = %{version}
Obsoletes:	%{name}-devel
Provides:	%{name}-devel = %{version}-%{release}
Provides:	%{lib_name_orig}-devel = %{version}-%{release}

%description -n	%{lib_name}-devel
The Python programming language's interpreter can be extended with
dynamically loaded extensions and can be embedded in other programs.
This package contains the header files and libraries needed to do
these types of tasks.

Install %{lib_name}-devel if you want to develop Python extensions.  The
python package will also need to be installed.  You'll probably also
want to install the python-docs package, which contains Python
documentation.

%package	docs
Summary:	Documentation for the Python programming language
Icon:		python-docs-logo.xpm
Requires:	python = %version
Group:		Development/Python

%description	docs
The python-docs package contains documentation on the Python
programming language and interpreter.  The documentation is provided
in ASCII text files and in LaTeX source files.

Install the python-docs package if you'd like to use the documentation
for the Python language.

%package -n	tkinter
Summary:	A graphical user interface for the Python scripting language
Group:		Development/Python
Icon:		python-tkinter-logo.xpm
Requires:	python = %version
Requires:       tcl tk

%description -n	tkinter
The Tkinter (Tk interface) program is an graphical user interface for
the Python scripting language.

You should install the tkinter package if you'd like to use a graphical
user interface for Python programming.

%package	base
Summary:	Python base files
Group:		Development/Python
Requires:	%{lib_name} = %{version}

%description	base
This packages contains the Python part that is used by the base packages
of a Mandriva Linux distribution.

%prep
%setup -q -n Python-%{version}
%patch3 -p1 -b .no-local-incpath
%patch4 -p1 -b .lib64
%patch5 -p1 -b .biarch-headers
%patch6 -p1 -b .gdbm
%patch7 -p0 -b .cve-2006-4980

autoconf

mkdir html
bzcat %{SOURCE1} | tar x  -C html

find . -type f -print0 | xargs -0 perl -p -i -e 's@/usr/local/bin/python@/usr/bin/python@'

%build
rm -f Modules/Setup.local
cat > Modules/Setup.local << EOF
linuxaudiodev linuxaudiodev.c
EOF

OPT="$RPM_OPT_FLAGS -g"
export OPT
%configure2_5x --with-threads --with-cycle-gc --with-cxx=g++ --without-libdb --enable-ipv6 --enable-shared

# fix build
perl -pi -e 's/^(LDFLAGS=.*)/$1 -lstdc++/' Makefile
%make

%check
# all tests must pass
make test TESTOPTS="-l -x test_linuxaudiodev -x test_nis"

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{_prefix}

# fix Makefile to get rid of reference to distcc
perl -pi -e "/^CC=/ and s/distcc/gcc/" Makefile

# set the install path
echo '[install_scripts]' >setup.cfg
echo 'install_dir='"${RPM_BUILD_ROOT}/usr/bin" >>setup.cfg

# python is not GNU and does not know fsstd
mkdir -p $RPM_BUILD_ROOT%{_mandir}
%makeinstall_std

(cd $RPM_BUILD_ROOT%{_libdir}; ln -sf libpython%{lib_major}.so.* libpython%{lib_major}.so)

# Provide a libpython%{dirver}.so symlink in /usr/lib/puthon*/config, so that
# the shared library could be found when -L/usr/lib/python*/config is specified
(cd $RPM_BUILD_ROOT%{_libdir}/python%{dirver}/config; ln -sf ../../libpython%{lib_major}.so .)

# emacs, I use it, I want it
mkdir -p $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp
install -m 644 Misc/python-mode.el $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp
emacs -batch -f batch-byte-compile $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp/python-mode.el

install -d $RPM_BUILD_ROOT%{_sysconfdir}/emacs/site-start.d
cat <<EOF >$RPM_BUILD_ROOT%{_sysconfdir}/emacs/site-start.d/%{name}.el
(setq auto-mode-alist (cons '("\\\\.py$" . python-mode) auto-mode-alist))
(autoload 'python-mode "python-mode" "Mode for python files." t)
EOF

# smtpd proxy
mv -f $RPM_BUILD_ROOT%{_bindir}/smtpd.py $RPM_BUILD_ROOT%{_libdir}/python%{dirver}/

# idle
cp Tools/scripts/idle $RPM_BUILD_ROOT%{_bindir}/idle

# modulator
cat << EOF > $RPM_BUILD_ROOT%{_bindir}/modulator
#!/bin/bash
exec %{_libdir}/python%{dirver}/site-packages/modulator/modulator.py
EOF
cp -r Tools/modulator $RPM_BUILD_ROOT%{_libdir}/python%{dirver}/site-packages/

# pynche
cat << EOF > $RPM_BUILD_ROOT%{_bindir}/pynche
#!/bin/bash
exec %{_libdir}/python%{dirver}/site-packages/pynche/pynche
EOF
rm -f Tools/pynche/*.pyw
cp -r Tools/pynche $RPM_BUILD_ROOT%{_libdir}/python%{dirver}/site-packages/

chmod 755 $RPM_BUILD_ROOT%{_bindir}/{idle,modulator,pynche}

ln -f Tools/modulator/README Tools/modulator/README.modulator
ln -f Tools/pynche/README Tools/pynche/README.pynche

rm -f modules-list.full
for n in $RPM_BUILD_ROOT%{_libdir}/python%{dirver}/*; do
  [ -d $n ] || echo $n
done >> modules-list.full

for mod in $RPM_BUILD_ROOT%{_libdir}/python%{dirver}/lib-dynload/* ; do
  [ `basename $mod` = _tkinter.so ] || echo $mod
done >> modules-list.full
sed -e "s|$RPM_BUILD_ROOT||g" < modules-list.full > modules-list


# menu support
mkdir -p $RPM_BUILD_ROOT%{_menudir}
cat > $RPM_BUILD_ROOT/%{_menudir}/tkinter << EOF
?package(tkinter): needs=x11 \
section="More Applications/Development/Development Environments" \
title="IDLE" \
longtitle="IDE for Python" \
command="%{_bindir}/idle" \
icon="development_environment_section.png"
EOF

rm -f include.list main.list
bzcat %{SOURCE2} | sed 's@%%{_libdir}@%{_libdir}@' > include.list
cat >> modules-list << EOF
%{_bindir}/python
%{_bindir}/python2.4
%{_bindir}/pydoc
%{_mandir}/man1/python*
%{_libdir}/python*/bsddb/
%{_libdir}/python*/curses/
%{_libdir}/python*/distutils/
%{_libdir}/python*/encodings/*
%{_libdir}/python*/lib-old/
%{_libdir}/python*/logging/
%{_libdir}/python*/xml/
%{_libdir}/python*/compiler/
%{_libdir}/python*/email/
%{_libdir}/python*/hotshot/
%{_libdir}/python*/site-packages/README
%{_libdir}/python*/plat-linux2/
%{_datadir}/emacs/site-lisp/python-mode.el*
EOF

LD_LIBRARY_PATH=$RPM_BUILD_ROOT%{_libdir} $RPM_BUILD_ROOT%{_bindir}/python %{SOURCE3} $RPM_BUILD_ROOT include.list modules-list > main.list

# fix non real scripts
chmod 644 $RPM_BUILD_ROOT%{_libdir}/python*/test/test_{binascii,grp,htmlparser}.py*
# fix python library not stripped
chmod u+w $RPM_BUILD_ROOT%{_libdir}/libpython2.4.so.1.0


mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/profile.d/

cat > $RPM_BUILD_ROOT%{_sysconfdir}/profile.d/python.sh << EOF
#!/bin/sh
if [ -f \$HOME/.pythonrc.py ] ; then
	export PYTHONSTARTUP=\$HOME/.pythonrc.py
else
	export PYTHONSTARTUP=/etc/pythonrc.py
fi
	
EOF

cat > $RPM_BUILD_ROOT/%{_sysconfdir}/profile.d/python.csh << EOF
if ( -f \${HOME}/.pythonrc.py ) then
	setenv PYTHONSTARTUP \${HOME}/.pythonrc.py
else
	setenv PYTHONSTARTUP /etc/pythonrc.py
endif

EOF

cat >  $RPM_BUILD_ROOT%{_sysconfdir}/pythonrc.py << EOF
# this add completion to python interpreter
import readline
import rlcompleter
# see readline man page for this
readline.parse_and_bind("set show-all-if-ambiguous on")
readline.parse_and_bind("tab: complete")

# you can place a file .pythonrc.py in your home to overrides this one
# but then, this file will not be sourced
EOF

chmod ugo+rx $RPM_BUILD_ROOT%{_sysconfdir}/profile.d/*

cat > README.mdk << EOF
Python interpreter support readline completion by default.
This is only used with the interpreter. In order to remove it,
you can :
1) unset PYTHONSTARTUP when you login
2) create a empty file $HOME/.pythonrc.py
3) change /etc/pythonrc.py
EOF

%multiarch_includes $RPM_BUILD_ROOT/usr/include/python*/pyconfig.h

%clean
rm -rf $RPM_BUILD_ROOT
rm -f modules-list main.list

%files -f main.list
%defattr(-, root, root, 755)
%doc README.mdk 
%dir %{_libdir}/python*/lib-dynload
%dir %{_libdir}/python*/site-packages
%config(noreplace) %{_sysconfdir}/emacs/site-start.d/%{name}.el
%{_sysconfdir}/profile.d/python.*
%config(noreplace) %{_sysconfdir}/pythonrc.py

%files -n %{lib_name}
%defattr(-,root,root)
%{_libdir}/libpython*.so.1*

%files -n %{lib_name}-devel
%defattr(-, root, root, 755)
%{_libdir}/libpython*.so
%dir %{_includedir}/python*
%multiarch %multiarch_includedir/python*/pyconfig.h
%{_includedir}/python*/*
%{_libdir}/python*/config/
%{_libdir}/python*/test/


%files docs
%defattr(-,root,root,755)
%doc html/*

%files -n tkinter
%defattr(-, root, root, 755)
%dir %{_libdir}/python*/lib-tk
%{_libdir}/python*/lib-tk/*.py*
%{_libdir}/python*/lib-dynload/_tkinter.so
%{_libdir}/python*/idlelib
%{_libdir}/python*/site-packages/modulator
%{_libdir}/python*/site-packages/pynche
%{_menudir}/tkinter
%{_bindir}/idle
%{_bindir}/pynche
%{_bindir}/modulator

%files base -f include.list
%defattr(-, root, root, 755)
%dir %{_libdir}/python*

%post -n %{lib_name} -p /sbin/ldconfig
%postun -n %{lib_name} -p /sbin/ldconfig

%post -n tkinter
%update_menus

%postun -n tkinter
%clean_menus

%changelog
* Fri Oct 06 2006 Vincent Danen <vdanen@mandriva.com> 2.4.1-5.1.20060mdk
- P7: security fix for CVE-2006-4980

* Sun Nov 06 2005 Michael Scherer <misc@mandriva.org> 2.4.1-5mdk
- add %%mkrel
- fix forbidden word

* Sat Oct  8 2005 Frederic Lepied <flepied@mandriva.com> 2.4.1-4mdk
- fixed get_config_h_filename in distutils for multiarch headers

* Thu Aug 25 2005 Frederic Lepied <flepied@mandriva.com> 2.4.1-3mdk
- fix bug #16553 by adding lib paths on 64 bit platforms

* Thu Jun  2 2005 Frederic Lepied <flepied@mandriva.com> 2.4.1-2mdk
- fixed python-base file list (bug #16002)

* Tue May 10 2005 Michael Scherer <misc@mandriva.org> 2.4.1-1mdk
- New release 2.4.1
- use %check
- remove patch 6, applied upstream

* Sat Feb 12 2005 Frederic Lepied <flepied@mandrakesoft.com> 2.4-5mdk
- fix MDKSA-2005:035 (patch6)

* Mon Jan 31 2005 Frederic Lepied <flepied@mandrakesoft.com> 2.4-4mdk
- multiarch tagging

* Thu Jan 20 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 2.4-3mdk
- rebuild for new readline

* Mon Jan 10 2005 Guillaume Rousse <guillomovitch@mandrake.org> 2.4-2mdk
- rediff patch 4

* Fri Dec 03 2004 Michael Scherer <misc@mandrake.org> 2.4-1mdk 
- 2.4
- remove patch 6 ( applied upstream ) 
- rediff patch 4 && 3
 
* Fri Nov 26 2004 Luca Berra <bluca@vodka.it> 2.3.4-8mdk 
- escape $HOME variable when creating profile.d script

* Tue Nov 16 2004 Christiaan Welvaart <cjw@daneel.dyndns.org> 2.3.4-7mdk
- rebuild for new libgdbm

* Thu Aug 19 2004 Michael Scherer <misc@mandrake.org> 2.3.4-6mdk 
- rebuild for new menu

* Fri Jul 16 2004 Michael Scherer <misc@mandrake.org> 2.3.4-5mdk 
- add tk as Requires ( thanks Goetz Waschk )

* Thu Jul 15 2004 Michael Scherer <misc@mandrake.org> 2.3.4-4mdk 
- fix #10278 
- add completion to the interpreter

* Wed Jun 30 2004 Christiaan Welvaart <cjw@daneel.dyndns.org> 2.3.4-3mdk
- really fix buildrequires

* Sun Jun 27 2004 Christiaan Welvaart <cjw@daneel.dyndns.org> 2.3.4-2mdk
- BuildRequires: gettext-devel

* Tue Jun  8 2004 Michael Scherer <misc@mandrake.org> 2.3.4-1mdk
- 2.3.4: see http://www.python.org/2.3.4/NEWS.html for details
- fix [DIRM]

* Thu Jun  3 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.3.3-6mdk
- buildrequires: tk
- rebuild against gcc3.4

* Fri May 21 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 2.3.3-5mdk
- s/Mandrake Linux/Mandrakelinux/
- fix buildrequires

* Fri Apr 23 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.3.3-4mdk
- relink against fixed libintl :-(

* Fri Apr 23 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.3.3-3mdk
- relink with new gettext

* Mon Feb 16 2004 Frederic Lepied <flepied@mandrakesoft.com> 2.3.3-2mdk
- added traceback.py* to python-base

* Tue Dec 23 2003 Frederic Lepied <flepied@mandrakesoft.com> 2.3.3-1mdk
- 2.3.3: see http://www.python.org/2.3.3/NEWS.html for details

* Thu Dec 18 2003 Frederic Lepied <flepied@mandrakesoft.com> 2.3.2-1mdk
- 2.3.2: see http://www.python.org/2.3.2/NEWS.html for details

* Mon Sep 22 2003 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.3-4mdk
- fix mklibnamification

* Sun Aug 31 2003 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.3-3mdk
- Fix lib64 patch and introduce sys.lib
- Patch6: 64-bit fixes to zipimport module

* Fri Aug  8 2003 Frederic Lepied <flepied@mandrakesoft.com> 2.3-2mdk
- corrected patch on distutils for lib64 management
- byte compile without storing the build path

* Thu Aug  7 2003 Frederic Lepied <flepied@mandrakesoft.com> 2.3-1mdk
- 2.3

* Mon Aug  4 2003 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.2.3-6mdk
- Fix libpython2.2.so symlink

* Thu Jul 31 2003 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.2.3-5mdk
- BuildRequires: termcap-devel

* Thu Jul 10 2003 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.2.3-4mdk
- Fix libification
- Patch8: Fix test_compile.py test for 64-bit platforms (CVS)

* Tue Jul  8 2003 Frederic Lepied <flepied@mandrakesoft.com> 2.2.3-3mdk
- remove compilation path from library
- compiled with ipv6 support (bug #2045)

* Wed Jun 25 2003 Stefan van der Eijk <stefan@eijk.nu> 2.2.3-2mdk
- remove redundant BuildRequires
- disable test on alpha & x86_64 for now, see SF bug: #660455 

* Wed Jun  4 2003 Frederic Lepied <flepied@mandrakesoft.com> 2.2.3-1mdk
- 2.2.3

* Mon May  5 2003 Frederic Lepied <flepied@mandrakesoft.com> 2.2.2-9mdk
- applied fix for tkinter from pysol site (bug #3760)

* Sat May  3 2003 Frederic Lepied <flepied@mandrakesoft.com> 2.2.2-8mdk
- fix tkinter (bug #3760)

* Mon Apr 14 2003 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.2.2-7mdk
- rebuild for tcl/tk

* Wed Feb  5 2003 Frederic Lepied <flepied@mandrakesoft.com> 2.2.2-6mdk
- rebuild for libssl

* Sat Jan  4 2003 Pixel <pixel@mandrakesoft.com> 2.2.2-5mdk
- robotparser patch, esp. fixes linkchecker on https (http://python.org/sf/499513)

* Thu Dec  5 2002 Frederic Lepied <flepied@mandrakesoft.com> 2.2.2-4mdk
- added BuildRequires db2-devel

* Thu Dec  5 2002 Frederic Lepied <flepied@mandrakesoft.com> 2.2.2-3mdk
- use %%mklibname

* Sat Nov 23 2002 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.2.2-2mdk
- s/distcc/gcc/ Makefile in case the former was used to build Python
- Patch5: Let h2py.py handle "-" in headers file name. This fixes
  build on x86-64 where kernel-headers are now bi-arch'ed.

* Fri Nov 15 2002 Frederic Lepied <flepied@mandrakesoft.com> 2.2.2-1mdk
- activated check by default
- 2.2.2

* Thu Nov 14 2002 Vincent Danen <vdanen@mandrakesoft.com> 2.2.1-15mdk
- include /usr/bin/pydoc and /usr/bin/python2.2
- clean up changelog to use (double-percent) everywhere; I think that was
  causing some wierd issues with newer rpm

* Wed Nov 13 2002 Vincent Danen <vdanen@mandrakesoft.com> 2.2.1-14mdk
- security fix (execvpe local execution vulnerability)

* Mon Sep  9 2002 Frederic Lepied <flepied@mandrakesoft.com> 2.2.1-13mdk
- put time.so in python-base

* Tue Aug 27 2002 David BAUDENS <baudens@mandrakesoft.com> 2.2.1-12mdk
- Fix icon (menu)

* Tue Aug 13 2002 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.2.1-11mdk
- Automated rebuild with gcc 3.2-0.3mdk

* Tue Aug 13 2002 Frederic Lepied <flepied@mandrakesoft.com> 2.2.1-10mdk
- fix setup step

* Mon Jul 29 2002 Frederic Crozat <fcrozat@mandrakesoft.com> 2.2.1-9mdk
- Remove NO_XALF from menu entries

* Thu Jul 25 2002 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.2.1-8mdk
- Automated rebuild with gcc3.2

* Wed Jul 24 2002 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.2.1-7mdk
- rebuild for new readline

* Mon Jul  1 2002 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.2.1-6mdk
- Update Patch4 to get correct "site-specific" directory

* Sun Jun 30 2002 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.2.1-5mdk
- Menu dir is %%_menudir, not %%_libdir/menu
- Update Source2 (baselist) to be %%_libdir compliant
- Update Patch1 (shlib) to really build importdl with PIC code
- Patch4: Look for and install libraries in the right directory
- Rpmlint fixes: configure-without-libdir-spec, hardcoded-library-path

* Sun Jun  2 2002 Stefan van der Eijk <stefan@eijk.nu> 2.2.1-4mdk
- BuildRequires

* Mon May 06 2002 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.2.1-3mdk
- Automated rebuild in gcc3.1 environment

* Thu Apr 18 2002 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.2.1-2mdk
- Patch2: Do use g++ as the linker when objects were built with g++,
  namely ccpython.o for the Python interpreter. Fix build with gcc3+.
- Patch3: Don't include /usr/local/* in search path

* Wed Apr 10 2002 Frederic Lepied <flepied@mandrakesoft.com> 2.2.1-1mdk
- 2.2.1

* Sun Feb 24 2002 Stew Benedict <sbenedict@mandrakesoft.com> 2.2-9mdk
- rebuild PPC against libdb3.3 - thx Jeff

* Tue Feb 12 2002 Frederic Lepied <flepied@mandrakesoft.com> 2.2-8mdk
- requires explictly the lib+version+release for python-base.

* Mon Feb 11 2002 Frederic Lepied <flepied@mandrakesoft.com> 2.2-7mdk
- don't use %%exclude
- patch for path (Ralf Ahlbrin)

* Thu Jan 17 2002 Frederic Lepied <flepied@mandrakesoft.com> 2.2-6mdk
- split python in python and python-base to lower the size of the
base packages .

* Wed Jan  9 2002 Frederic Lepied <flepied@mandrakesoft.com> 2.2-5mdk
- added missing subdirs.

* Wed Jan 09 2002 David BAUDENS <baudens@mandrakesoft.com> 2.2-4mdk
- Fix menu entry (png icon)

* Thu Jan  3 2002 Frederic Lepied <flepied@mandrakesoft.com> 2.2-3mdk
- bytecompile with a -d option to avoid putting the RPM_BUILD_ROOT in
the byte compiled file.

* Wed Jan  2 2002 Frederic Lepied <flepied@mandrakesoft.com> 2.2-2mdk
- rebuild to have the right dependencies

* Sun Dec 23 2001 Frederic Lepied <flepied@mandrakesoft.com> 2.2-1mdk
- 2.2

* Wed Oct 24 2001 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.1.1-5mdk
- Libification
- Enhanced Patch2 thanks to a Debian patch so that a shared library is
  built as well. Fix linuxconf, koffice builds on IA-64.

* Tue Oct  9 2001 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.1.1-4mdk
- Remove BuildRequires: libxode1-devel
- Remove Requires: libtcl8.3.so libtk8.3.so for tkinter

* Thu Aug 30 2001 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.1.1-3mdk
- Patch2: DSO must have PIC code. Actually, kludge the configure script
  if MACHDEP is set
- Add BuildRequires: autoconf

* Mon Aug 20 2001 Frederic Lepied <flepied@mandrakesoft.com> 2.1.1-2mdk
- updated doc (#4263).

* Fri Jul 20 2001 Frederic Lepied <flepied@mandrakesoft.com> 2.1.1-1mdk
- 2.1.1

* Tue Jul  3 2001 Frederic Lepied <flepied@mandrakesoft.com> 2.1-2mdk
- rebuild for db3.2

* Fri Apr 27 2001 Frederic Lepied <flepied@mandrakesoft.com> 2.1-1mdk
- 2.1

* Wed Apr 11 2001 Frederic Crozat <fcrozat@mandrakesoft.com> 2.0-9mdk
- Correct GNOME menu entry

* Sun Apr  8 2001 Frederic Lepied <flepied@mandrakesoft.com> 2.0-8mdk
- added missing xml directory
- added an optional make test at the end of the %%build section

* Fri Mar 30 2001 Frederic Lepied <flepied@mandrakesoft.com> 2.0-6mdk
- correct launching of scripts (#2802)

* Tue Mar 27 2001 Frederic Lepied <flepied@mandrakesoft.com> 2.0-5mdk
- added libtermcap-devel to BuildRequires.

* Sat Mar 24 2001 David BAUDENS <baudens@mandrakesoft.com> 2.0-4mdk
- BuildRequires: libxode1-devel
- Requires: %%version-%%release and not only %%version

* Mon Mar 19 2001 Pixel <pixel@mandrakesoft.com> 2.0-3mdk
- fix the python.el (\\. -> \\\\.)

* Fri Dec  8 2000 Frederic Lepied <flepied@mandrakesoft.com> 2.0-2mdk
- added blt and expat-devel BuildRequires:

* Fri Nov 17 2000 Frederic Lepied <flepied@mandrakesoft.com> 2.0-1mdk
- 2.0 (95 tests OK. 12 tests skipped: test_al test_cd test_cl test_dl test_gl test_imgfile test_largefile
test_linuxaudiodev test_nis test_sunaudiodev test_winreg test_winsound)
- added emacs mode
- html doc.

* Wed Sep 27 2000 Frederic Lepied <flepied@mandrakesoft.com> 1.5.2-12mdk
- removed dependency on tkinter for python to avoid loop.

* Mon Sep 11 2000 Frederic Lepied <flepied@mandrakesoft.com> 1.5.2-11mdk
- fixed some hardcoded paths (Geoffrey Lee).
- removed menu entry for interpreter.

* Thu Aug 10 2000 Guillaume Cottenceau <gc@mandrakesoft.com> 1.5.2-10mdk
- fixed typo %%updates_menus -> %%update_menus

* Mon Aug 07 2000 Frederic Lepied <flepied@mandrakesoft.com> 1.5.2-9mdk
- automatically added BuildRequires

* Thu Aug  3 2000 Chmouel Boudjnah <chmouel@mandrakesoft.com> 1.5.2-8mdk
- Merge rh patch.
- Macros.
- compile with new tcl.

* Tue May  9 2000 Frederic Lepied <flepied@mandrakesoft.com> 1.5.2-7mdk
- added locale module.

* Thu Mar 30 2000 Frederic Lepied <flepied@mandrakesoft.com> 1.5.2-6mdk
- menu

* Tue Mar  7 2000 Frederic Lepied <flepied@mandrakesoft.com> 1.5.2-5mdk
- idle 0.5.
- compiled with optimization.

* Fri Jan 14 2000 Frederic Lepied <flepied@mandrakesoft.com> 1.5.2-4mdk

- added a BuildRequires.

* Sat Dec 4 1999 Florent Villard <warly@mandrakesoft.com>
- add idle, pynche and modulator in the package

* Tue Oct 19 1999 Chmouel Boudjnah <chmouel@mandrakesoft.com>
- Merge with redhat changes.
- added modulator, and pynche to the python-tools package(r)
- using a files list in the %%files section for python-tools(r)
- added conflicts/requires between subpackages so that you cannot
  have an older tkinter installed with a new python.(r)
- added more tools(r)
- rebuild to fix broken tkinter.(r)
- fixed bogus /usr/local/bin/python requirements.(r)
- added patch to import global symbols until we get libtool patched(r)

* Fri Aug 20 1999 Pablo Saratxaga <pablo@mandrakesoft.com>
- updated to 1.5.2
- updated patches
- use macro %%{_arch} instead of %%{_target_cpu} for file paths

* Tue Apr 13 1999 Chmouel Boudjnah <chmouel@mandrakesoft.com>
- Remove the dbm support (doen't work with GLBC2.1)

* Sat Apr 10 1999 Bernhard Rosenkraenzer <bero@linux-mandrake.com>
- Mandrake adaptions
- add de locale
- fix handling of RPM_OPT_FLAGS

* Thu Feb 11 1999 Michael Johnson <johnsonm@redhat.com>
- added mpzmodule at user request (uses gmp)
- added bsddbmodule at user request (uses db 1.85 interface)

* Mon Feb 08 1999 Michael Johnson <johnsonm@redhat.com>
- add --with-threads at user request
- clean up spec file

* Fri Jan 08 1999 Michael K. Johnson <johnsonm@redhat.com>
- New libc changes ndbm.h to db1/ndbm.h and -ldb to -ldb1

* Thu Sep  3 1998 Jeff Johnson <jbj@redhat.com>
- recompile for RH 5.2.

* Wed May 06 1998 Cristian Gafton <gafton@redhat.com>
- python-docs used to require /usr/bin/sed. Changed to /bin/sed instead

* Wed Apr 29 1998 Cristian Gafton <gafton@redhat.com>
- fixed the spec file for version 1.5.1
- buildroot (!)

* Mon Apr 20 1998 Michael K. Johnson <johnsonm@redhat.com>
- updated to python 1.5.1
- created our own Python-Doc tar file from 1.5 to substitute for the
  not-yet-released Doc package.
- build _tkinter properly
- use readline again
- build crypt module again
- install rand replacement module
- added a few modules

* Thu Apr 09 1998 Erik Troan <ewt@redhat.com>
- updated to python 1.5
- made /usr/lib/python1.5 file list automatically generated

* Tue Nov 04 1997 Michael K. Johnson <johnsonm@redhat.com>
- Fixed dependencies for python and tkinter

* Mon Nov 03 1997 Michael K. Johnson <johnsonm@redhat.com>
- pulled out tk-related stuff into tkinter package

* Fri Oct 10 1997 Erik Troan <ewt@redhat.com>
- bunches of scripts used /usr/local/bin/python instead of /usr/bin/python

* Tue Sep 30 1997 Erik Troan <ewt@redhat.com>
- updated for tcl/tk 8.0

* Thu Jul 10 1997 Erik Troan <ewt@redhat.com>
- built against glibc
